@@ -1,6 +1,7 @@
 import pymysql, psycopg2
 from dbutils.pooled_db import PooledDB
 import psycopg2.extras
+
 Log = None
 
 
@@ -212,7 +213,7 @@ class PgHelper(Singleton2):
         if format:
             cursor = conn.cursor()
         else:
-            cursor = conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
+            cursor = conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
         return conn, cursor
 
     def executeParam(self, cursor, sql, Param):
@@ -267,6 +268,7 @@ class PgHelper(Singleton2):
                         flag = True
                         break
                 if flag:
+                    result = [dict(v) for v in result]
                     return result
                 else:
                     return []
@@ -290,6 +292,7 @@ class PgHelper(Singleton2):
                         flag = True
                         break
                 if flag:
+                    result = dict(result)
                     return result
                 else:
                     return None
